<?php
include("conexion.php");
date_default_timezone_set("America/Mexico_City");

$folio = $_POST['folio'];
$consfolio = $_POST['folio'];
$entrega = $_POST['entrega'];
$prod = $_POST['prod'];
$fecha = date("Y-m-d");

$entregados = 0;

//============== INSERTAR ENTREGADOS
$total = sizeof($prod);

@$idcambio = $_POST['idcambio'];
@$cambio = $_POST['cambio'];

$prodcambio[] = 0;
$prodidcambio[] = 0;
for ($x = 0; $x < sizeof($prod); $x++) {
	if ($entrega[$x] == "") {
	} else {
		//FOR PARA REGISTRAR CAMBIOS EN CONTABLES VARIABLES
		if (isset($_POST['idcambio'])) {			
			for ($y = 0; $y < sizeof($idcambio); $y++) {
				$con1 = "SELECT clave1,clave2 FROM cambiosventa WHERE idCambio='$idcambio[$y]'";
				$res1 = mysql_query($con1, $conex) or die("No se realiz con1");
				$clave1 = mysql_result($res1, 0, 'clave1');
				$clave2 = mysql_result($res1, 0, 'clave2');

				if ($prod[$x] == $clave1) {
					$prodcambio[$x] = $cambio[$y];
					$prodidcambio[$x] = $idcambio[$y];
				} else {
					if ($prod[$x] == $clave2) {
						$prodcambio[$x] = $cambio[$y];
					}
				}
			}
			if (@$prodcambio[$x] != 0) {
				echo $prodidcambio[$x] . " cambia " . $prod[$x] . " por " . $prodcambio[$x] . "<br>";

				//INICIA ACTUALIZACION DEL CAMBIO
				$con2 = "UPDATE contenido_salida SET idProducto='$prodcambio[$x]' WHERE idSalida='$folio' and idProducto='$prod[$x]'";
				$res2 = mysql_query($con2, $conex) or die("No se realiz con2");

				$con3 = "UPDATE cambiosventa SET clave2='$prodcambio[$x]' WHERE idCambio='$prodidcambio[$x]'";
				$res3 = mysql_query($con3, $conex) or die("No se realiz con3");
				//TERMINA ACTUALIZACION DEL CAMBIO
				$prod[$x] = $prodcambio[$x];
			}
		}


		//echo $prod[$x]."<br>";
		//VALIDO SI ES INCONTABLE PARA NO ACTUALIZAR SALIDA	
		$cons411 = "SELECT clasificacion FROM productos WHERE clave='$prod[$x]'";
		$res411 = mysql_query($cons411, $conex) or die(mysql_error());
		$clas1 = mysql_result($res411, 0, 'clasificacion');
		if ($clas1 == 'Incontables' or $clas1 == 'Materiales de impresion' or $clas1 == 'Liquidos - polvos') {
			$cons04 = "INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$prod[$x]','$entrega[$x]','$fecha')";
			$res04 = mysql_query($cons04, $conex) or die("No se realizo cons04");
		} else {
			$cons004 = "INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$prod[$x]','$entrega[$x]','$fecha')";
			$res004 = mysql_query($cons004, $conex) or die("No se realizo cons004");

			$cons400 = "SELECT existencia FROM almacenes WHERE idProducto='$prod[$x]'";
			$res400 = mysql_query($cons400, $conex) or die("No se pudo consultar existencias cons400");
			$existen001 = mysql_result($res400, 0, 'existencia');

			$nueva = 0;
			$nueva = $existen001 - $entrega[$x];

			$cons410 = "UPDATE almacenes SET existencia='$nueva' WHERE idProducto='$prod[$x]'";
			$res410 = mysql_query($cons410, $conex) or die("No se pudo actualizar existencia cons410");
		}
	}
	/*	
	if ($entrega[$x]== "")
	{}
	else
	{
		//VALIDO SI ES INCONTABLE PARA NO ACTUALIZAR SALIDA	
		$cons411="SELECT clasificacion FROM productos WHERE clave='$prod[$x]'";
		$res411=mysql_query($cons411,$conex) or die (mysql_error());
		$clas1=mysql_result($res411,0,'clasificacion');
		if($clas1 == 'Incontables')
		{
			$cons04="INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$prod[$x]','$entrega[$x]','$fecha')";
			$res04=mysql_query($cons04,$conex) or die ("No se realizo cons04");
		}
		else
		{
			$cons004="INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$prod[$x]','$entrega[$x]','$fecha')";
			$res004=mysql_query($cons004,$conex) or die ("No se realizo cons004");
			
			$cons400="SELECT existencia FROM almacenes WHERE idProducto='$prod[$x]'" ;
			$res400=mysql_query($cons400,$conex) or die ("No se pudo consultar existencias cons400");
			$existen001=mysql_result($res400,0,'existencia');
			
			$nueva=0;
			$nueva=$existen001 - $entrega[$x];

			$cons410="UPDATE almacenes SET existencia='$nueva' WHERE idProducto='$prod[$x]'" ;
			$res410=mysql_query($cons410,$conex) or die ("No se pudo actualizar existencia cons410");
		}
		
//AQUI VA COMENTADO
		if ($existencia < $entrega[$x])
		{
			$nueva=$existencia - $entrega[$x];
			
			$cons4="INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$prod[$x]','$entrega[$x]','$fecha')";
			$res4=mysql_query($cons4,$conex) or die ("No se realizo cons4");
			
			$cons41="UPDATE almacenes SET existencia='$nueva' WHERE idProducto='$prod[$x]'" ;
			$res41=mysql_query($cons41,$conex) or die ("No se pudo actualizar existencia");
		}
		else
		{}
	}
*/
}

//================== REALIZAR CAMBIOS DE MATERIAL
/*
echo "Listado de cambios<br>";

@$idcambio=$_POST['idcambio'];
@$cambio=$_POST['cambio'];
echo sizeof($idcambio)." -><br>";

if ($idcambio != "")
{
		for($x=0; $x < sizeof($idcambio); $x++)
		{
		
		$con1="SELECT clave1,clave2 FROM cambiosventa WHERE idCambio='$idcambio[$x]'";
		$res1=mysql_query($con1,$conex) or die ("No se realiz con1");
		$clave1=mysql_result($res1,0,'clave1');
		$clave2=mysql_result($res1,0,'clave2');
		
		echo $idcambio[$x]." - ";
		echo $clave1." por ".$cambio[$x]." <br>";

			//echo $idcambio[$x]." --- ";
			//echo $cambio[$x]." <br>";

			//OBTENER SALIDA Y CLAVE PARA ACTUALIZAR EN LA VENTA
			$con1="SELECT clave1,clave2 FROM cambiosventa WHERE idCambio='$idcambio[$x]'";
			$res1=mysql_query($con1,$conex) or die ("No se realiz con1");
			$clave1=mysql_result($res1,0,'clave1');
			$clave2=mysql_result($res1,0,'clave2');
			
			if ($clave2=='')
			{
				
				$con2="UPDATE contenido_salida SET idProducto='$cambio[$x]' WHERE idSalida='$folio' and idProducto='$clave1'";
				$res2=mysql_query($con2,$conex) or die ("No se realiz con2");

				$cons40="UPDATE entregas_material SET clave='$cambio[$x]' WHERE idSalida='$folio' and clave='$clave1'";
				$res40=mysql_query($cons40,$conex) or die ("No se realizo cons40_1");
			}
			else
			{
				$con2="UPDATE contenido_salida SET idProducto='$cambio[$x]' WHERE idSalida='$folio' and idProducto='$clave2'";
				$res2=mysql_query($con2,$conex) or die ("No se realiz con2");

				$cons40="UPDATE entregas_material SET clave='$cambio[$x]' WHERE idSalida='$folio' and clave='$clave2'";
				$res40=mysql_query($cons40,$conex) or die ("No se realizo cons40_2");
			}

			$con3="UPDATE cambiosventa SET clave2='$cambio[$x]' WHERE idCambio='$idcambio[$x]'";
			$res3=mysql_query($con3,$conex) or die ("No se realiz con3");

		}
}
*/

//=================== INSERCION DE PRODUCTO NUEVO
$cuantos = $_POST['cuantos'];
//echo $cuantos;

for ($x = 1; $x <= $cuantos; $x++) {
	@$variable1 = "nombre" . $x . "_hidden";
	$clave = $_POST[$variable1];
	@$variable2 = "cantidad" . $x;
	$cantidad = $_POST[$variable2];

	//echo $clave." --> ".$cantidad."<br>";

	if ($clave != "") {
		if ($cantidad != "") {
			//verifico si existe el producto ya en el paquete
			$cons10 = "SELECT * FROM contenido_salida WHERE idProducto='$clave' and idSalida='$consfolio'";
			$res10 = mysql_query($cons10, $conex) or die("No se realizo cons10");
			$num_filas = mysql_num_rows($res10);

			if ($num_filas == 0) {
				//$cons30="INSERT INTO contenido_salida (idSalida,idProducto,cantidad,entregado) VALUES ('$consfolio','$clave','$cantidad','Si')";
				$cons30 = "INSERT INTO contenido_salida (idSalida,idProducto,cantidad,entregado) VALUES ('$consfolio','$clave',0,'Si')";
				$res30 = mysql_query($cons30, $conex) or die("No se realiz cons30");

				$cons40 = "INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$clave','$cantidad','$fecha')";
				$res40 = mysql_query($cons40, $conex) or die("No se realizo cons4");

				$mensaje = "Producto " . $clave . " agregado";

				// ================== VALIDO SI YA EXISTE UNO DEL MISMO TIPO LE RESTO LA DISPONIBILIDAD
				/*
				$query01="SELECT nombre FROM productos WHERE clave='$clave'";
				$result01=mysql_query($query01,$conex) or die ("No se realizo query01");
				$nombre1=mysql_result($result01,0,'nombre');
				$palabra1 = explode(" ", $nombre1);
				$palabranueva=$palabra1[0]." ".$palabra1[1];
				
				$query02="SELECT idProducto,cantidad FROM contenido_salida WHERE idSalida='$consfolio'";
				$result02=mysql_query($query02,$conex) or die ("No se realizo query02");		
				while ($fila = mysql_fetch_array($result02))
				{
					$query03="SELECT nombre FROM productos WHERE clave='$fila[0]'";
					$result03=mysql_query($query03,$conex) or die ("No se realizo query03");		
					$nombre2=mysql_result($result03,0,'nombre');
					$palabra2 = explode(" ",$nombre2);
					@$palabraexistente=$palabra2[0]." ".$palabra2[1];
					
					if($palabranueva==$palabraexistente)
					{
						$nuevacantidad = $fila[1] - $cantidad;
						$query04="UPDATE contenido_salida SET cantidad='$nuevacantidad' WHERE idSalida='$consfolio' and idProducto='$fila[0]'";
						$result04=mysql_query($query04,$conex) or die ("No se realiz query04");
					}
					else
					{
						if($palabra1[0]==$palabra2[0])
						{
							$nuevacantidad=$fila[1]-$cantidad;
							$query04="UPDATE contenido_salida SET cantidad='$nuevacantidad' WHERE idSalida='$consfolio' and idProducto='$fila[0]'";
							$result04=mysql_query($query04,$conex) or die ("No se realiz query04");
						}
					}
				}*/
			} else {
				//ACTUALIZACION DE CANTIDAD CUANDO ES EL MISMO PRODUCTO
				/*
				$cant_anterior=mysql_result($res10,0,'cantidad');
				$cant_final=$cant_anterior + $cantidad;
				
				$cons20="UPDATE contenido_salida SET cantidad='$cant_final',entregado='Si' WHERE idSalida='$consfolio' and idProducto='$clave'";
				$res20=mysql_query($cons20,$conex) or die ("No se realiz cons20");
				*/

				$cons40 = "INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$clave','$cantidad','$fecha')";
				$res40 = mysql_query($cons40, $conex) or die("No se realizo cons4");

				$mensaje = "Producto " . $clave . " agregado";
			}

			// ACTUALIZO INVENTARIO 
			//VALIDO SI ES INCONTABLE PARA NO ACTUALIZAR SALIDA	
			$cons412 = "SELECT clasificacion FROM productos WHERE clave='$clave'";
			$res412 = mysql_query($cons412, $conex) or die(mysql_error());
			@$clas = mysql_result($res412, 0, 'clasificacion');
			if ($clas != 'Incontables' and $clas != 'Materiales de impresion' and $clas != 'Liquidos - polvos') {
				$nueva = 0;
				$cons401 = "SELECT existencia FROM almacenes WHERE idProducto='$clave'";
				$res401 = mysql_query($cons401, $conex) or die("No se pudo consultar existencias cons401");
				@$existencia = mysql_result($res401, 0, 'existencia');

				$nueva = $existencia - $cantidad;

				$cons402 = "UPDATE almacenes SET existencia='$nueva' WHERE idProducto='$clave'";
				$res402 = mysql_query($cons402, $conex) or die("No se pudo actualizar existencia cons402");
			}
		} else { //$mensaje="Para agregar el producto falta la cantidad entregada!";
			$mensaje = "";
		}
	} else { //$mensaje="Para agregar producto falta que seleccione alguno!"; 
		$mensaje = "";
	}
}

// GUARDO OBSERVACIONES
$observaciones = $_POST['observaciones'];

$consob = "UPDATE salida SET observaciones='$observaciones' WHERE idSalida='$consfolio'";
$resob = mysql_query($consob, $conex) or die("No se realiz consob");
?>

<!doctype html>
<html>

<head>
	<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
	<title>Clinisys :. Universidad Cuauht&eacute;moc</title>
	<style>
		.style5 {
			font-family: Verdana, Arial, Helvetica, sans-serif;
			font-style: italic;
			font-size: 16px;
			color: #02387E;
		}
	</style>
	<script>
		setTimeout('document.form1.submit();', 2000);
	</script>
</head>

<body>
	<div align="center" style="padding-top:100px;">
		<span class="style5">Procesando salida...</span><br><img src="img/ajax-loader.gif">
	</div>
	<form id="form1" name="form1" method="post" action="detallesalida.php">
		<input name="folio" type="hidden" value="<?php echo $consfolio; ?>" />
	</form>
</body>

</html>